@@ -1,5 +1,5 @@
 document.getElementById("Contents").innerHTML='\
-    <ul><li><input type="checkbox" id="07"><label for="07">宏与编程</label><ul>\
+    <ul><li><input type="checkbox" id="07"><label for="07">宏与脚本</label><ul>\
     <li><input type="checkbox" id="0701"><label for="0701">常规信息及用户界面用法</label><ul>\
     <li><a target="_top" href="zh-CN/text/sbasic/shared/main0601.html">LibreOffice Basic 帮助</a></li>\
     <li><a target="_top" href="zh-CN/text/sbasic/shared/01000000.html">使用 LibreOffice Basic 编程</a></li>\
@@ -124,6 +124,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="zh-CN/text/sbasic/shared/03090202.html">For...Next 语句</a></li>\
     <li><a target="_top" href="zh-CN/text/sbasic/shared/03120301.html">Format 函数</a></li>\
     <li><a target="_top" href="zh-CN/text/sbasic/shared/03150000.html">FormatDateTime 函数 [VBA]</a></li>\
+    <li><a target="_top" href="zh-CN/text/sbasic/shared/03170010.html">FormatNumber 函数 [VBA]</a></li>\
     <li><a target="_top" href="zh-CN/text/sbasic/shared/03020102.html">FreeFile 函数</a></li>\
     <li><a target="_top" href="zh-CN/text/sbasic/shared/03090405.html">FreeLibrary 函数</a></li>\
     <li><a target="_top" href="zh-CN/text/sbasic/shared/03090406.html">函数语句</a></li>\
@@ -297,7 +298,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="zh-CN/text/sbasic/guide/access2base.html">Access2Base</a></li>\
 		</ul></li>\
 	</ul></li></ul>\
-    <ul><li><input type="checkbox" id="08"><label for="08">电子表格</label><ul>\
+    <ul><li><input type="checkbox" id="08"><label for="08">电子表格 (Calc)</label><ul>\
     <li><input type="checkbox" id="0801"><label for="0801">常规信息及用户界面用法</label><ul>\
     <li><a target="_top" href="zh-CN/text/scalc/main0000.html">欢迎使用 LibreOffice Calc 帮助</a></li>\
     <li><a target="_top" href="zh-CN/text/scalc/main0503.html">LibreOffice Calc 电子表格的功能</a></li>\
@@ -437,7 +438,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="zh-CN/text/scalc/guide/cellreference_dragdrop.html">通过拖放来引用单元格</a></li>\
     <li><a target="_top" href="zh-CN/text/scalc/guide/address_auto.html">将名称识别为地址</a></li>\
 		</ul></li>\
-    <li><input type="checkbox" id="0812"><label for="0812">查看，选择，复制</label><ul>\
+    <li><input type="checkbox" id="0812"><label for="0812">查看、选择、复制</label><ul>\
     <li><a target="_top" href="zh-CN/text/scalc/guide/table_view.html">修改表格视图</a></li>\
     <li><a target="_top" href="zh-CN/text/scalc/guide/formula_value.html">显示公式或数值</a></li>\
     <li><a target="_top" href="zh-CN/text/scalc/guide/line_fix.html">行或列作为标题固定</a></li>\
@@ -470,14 +471,14 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="zh-CN/text/scalc/guide/validity.html">单元格内容的有效性</a></li>\
 		</ul></li>\
 	</ul></li></ul>\
-    <ul><li><input type="checkbox" id="05"><label for="05">图表</label><ul>\
+    <ul><li><input type="checkbox" id="05"><label for="05">图表与图示</label><ul>\
     <li><input type="checkbox" id="0501"><label for="0501">常规信息</label><ul>\
     <li><a target="_top" href="zh-CN/text/schart/main0000.html">LibreOffice 中的图表</a></li>\
     <li><a target="_top" href="zh-CN/text/schart/main0503.html">LibreOffice 图表功能</a></li>\
     <li><a target="_top" href="zh-CN/text/schart/04/01020000.html">图表的快捷键</a></li>\
 		</ul></li>\
 	</ul></li></ul>\
-    <ul><li><input type="checkbox" id="01"><label for="01">安装</label><ul>\
+    <ul><li><input type="checkbox" id="01"><label for="01">LibreOffice 安装</label><ul>\
     <li><a target="_top" href="zh-CN/text/shared/guide/ms_doctypes.html">修改 Microsoft Office 文档类型的关联</a></li>\
     <li><a target="_top" href="zh-CN/text/shared/01/profile_safe_mode.html">安全模式</a></li>\
 	</ul></li></ul>\
@@ -503,7 +504,6 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="zh-CN/text/shared/optionen/01010200.html">常规</a></li>\
     <li><a target="_top" href="zh-CN/text/shared/optionen/01010300.html">路径</a></li>\
     <li><a target="_top" href="zh-CN/text/shared/optionen/01010400.html">写作辅助</a></li>\
-    <li><a target="_top" href="zh-CN/text/shared/optionen/01010500.html">颜色</a></li>\
     <li><a target="_top" href="zh-CN/text/shared/optionen/01010600.html">常规</a></li>\
     <li><a target="_top" href="zh-CN/text/shared/optionen/01010700.html">字体</a></li>\
     <li><a target="_top" href="zh-CN/text/shared/optionen/01010800.html">视图</a></li>\
@@ -575,7 +575,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="zh-CN/text/swriter/01/addsignatureline.html">在文本文档中添加签名行</a></li>\
     <li><a target="_top" href="zh-CN/text/swriter/01/signsignatureline.html">签署签名行</a></li>\
                 </ul></li>\
-    <li><input type="checkbox" id="1008"><label for="1008">打印，传真，发送</label><ul>\
+    <li><input type="checkbox" id="1008"><label for="1008">打印、传真、发送</label><ul>\
     <li><a target="_top" href="zh-CN/text/shared/guide/labels_database.html">打印地址标签</a></li>\
     <li><a target="_top" href="zh-CN/text/shared/guide/print_blackwhite.html">黑白打印</a></li>\
     <li><a target="_top" href="zh-CN/text/shared/guide/email.html">将文档作为电子邮件发送</a></li>\
@@ -595,7 +595,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="zh-CN/text/shared/guide/dragdrop_fromgallery.html">从图库复制图形</a></li>\
     <li><a target="_top" href="zh-CN/text/shared/guide/dragdrop_table.html">复制电子表格区域至文本文档</a></li>\
 		</ul></li>\
-    <li><input type="checkbox" id="1012"><label for="1012">图表</label><ul>\
+    <li><input type="checkbox" id="1012"><label for="1012">图表与图示</label><ul>\
     <li><a target="_top" href="zh-CN/text/shared/guide/chart_insert.html">插入图表</a></li>\
     <li><a target="_top" href="zh-CN/text/schart/main0000.html">LibreOffice 中的图表</a></li>\
 		</ul></li>\
@@ -661,7 +661,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="zh-CN/text/shared/guide/numbering_stop.html">关闭单独段落的项目符号与编号</a></li>\
 		</ul></li>\
 	</ul></li></ul>\
-    <ul><li><input type="checkbox" id="09"><label for="09">数据库功能</label><ul>\
+    <ul><li><input type="checkbox" id="09"><label for="09">数据库功能 (Base)</label><ul>\
     <li><input type="checkbox" id="0901"><label for="0901">常规信息</label><ul>\
     <li><a target="_top" href="zh-CN/text/shared/explorer/database/main.html">LibreOffice 数据库</a></li>\
     <li><a target="_top" href="zh-CN/text/shared/guide/database_main.html">数据库摘要</a></li>\
@@ -675,7 +675,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="zh-CN/text/shared/guide/data_enter_sql.html">执行 SQL 命令</a></li>\
 		</ul></li>\
 	</ul></li></ul>\
-    <ul><li><input type="checkbox" id="04"><label for="04">演示文稿与绘图</label><ul>\
+    <ul><li><input type="checkbox" id="04"><label for="04">演示文稿与绘图 (Impress/Draw)</label><ul>\
     <li><input type="checkbox" id="0401"><label for="0401">常规信息及用户界面用法</label><ul>\
     <li><a target="_top" href="zh-CN/text/simpress/main0000.html">欢迎使用 LibreOffice Impress 帮助</a></li>\
     <li><a target="_top" href="zh-CN/text/sdraw/main0000.html">欢迎使用 LibreOffice Draw 帮助</a></li>\
@@ -713,7 +713,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="zh-CN/text/simpress/main0209.html">标尺</a></li>\
     <li><a target="_top" href="zh-CN/text/simpress/main0210.html">绘图栏</a></li>\
     <li><a target="_top" href="zh-CN/text/simpress/main0211.html">大纲工具栏</a></li>\
-    <li><a target="_top" href="zh-CN/text/simpress/main0212.html">幻灯片浏览栏</a></li>\
+    <li><a target="_top" href="zh-CN/text/simpress/main0212.html">「幻灯片浏览」栏</a></li>\
     <li><a target="_top" href="zh-CN/text/simpress/main0213.html">选项栏</a></li>\
     <li><a target="_top" href="zh-CN/text/simpress/main0214.html">图像栏</a></li>\
     <li><a target="_top" href="zh-CN/text/shared/main0201.html">标准工具栏</a></li>\
@@ -779,7 +779,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="zh-CN/text/simpress/guide/animated_gif_create.html">创建动画 GIF 图像</a></li>\
          </ul></li>\
     <li><input type="checkbox" id="0407"><label for="0407">对象、图形和位图</label><ul>\
-    <li><a target="_top" href="zh-CN/text/sdraw/guide/combine_etc.html">组合对象和构造形状</a></li>\
+    <li><a target="_top" href="zh-CN/text/sdraw/guide/combine_etc.html">结合对象与构造形状</a></li>\
     <li><a target="_top" href="zh-CN/text/sdraw/guide/draw_sector.html">绘制扇形和圆缺</a></li>\
     <li><a target="_top" href="zh-CN/text/sdraw/guide/duplicate_object.html">复制对象</a></li>\
     <li><a target="_top" href="zh-CN/text/sdraw/guide/rotate_object.html">旋转对象</a></li>\
@@ -820,7 +820,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="zh-CN/text/simpress/guide/rehearse_timings.html">幻灯片更换的排练计时</a></li>\
          </ul></li>\
      </ul></li></ul>\
-    <ul><li><input type="checkbox" id="03"><label for="03">公式</label><ul>\
+    <ul><li><input type="checkbox" id="03"><label for="03">公式 (Math)</label><ul>\
     <li><input type="checkbox" id="0301"><label for="0301">常规信息及用户界面用法</label><ul>\
     <li><a target="_top" href="zh-CN/text/smath/main0000.html">欢迎使用 LibreOffice Math 帮助</a></li>\
     <li><a target="_top" href="zh-CN/text/smath/main0503.html">LibreOffice Math 功能</a></li>\
@@ -840,7 +840,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="zh-CN/text/smath/guide/parentheses.html">插入括号</a></li>\
 		</ul></li>\
 	</ul></li></ul>\
-    <ul><li><input type="checkbox" id="02"><label for="02">文本文档</label><ul>\
+    <ul><li><input type="checkbox" id="02"><label for="02">文本文档 (Writer)</label><ul>\
     <li><input type="checkbox" id="0201"><label for="0201">常规信息及用户界面用法</label><ul>\
     <li><a target="_top" href="zh-CN/text/swriter/main0000.html">欢迎使用 LibreOffice Writer 文本文档帮助</a></li>\
     <li><a target="_top" href="zh-CN/text/swriter/main0503.html">LibreOffice Writer 的主要功能</a></li>\
@@ -966,7 +966,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="zh-CN/text/swriter/guide/header_pagestyles.html">定义不同的页眉与页脚</a></li>\
     <li><a target="_top" href="zh-CN/text/swriter/guide/header_with_chapter.html">在页眉或页脚中插入章节名称和编号</a></li>\
     <li><a target="_top" href="zh-CN/text/swriter/guide/shortcut_writing.html">输入时应用文本格式</a></li>\
-    <li><a target="_top" href="zh-CN/text/swriter/guide/reset_format.html">重设字体属性</a></li>\
+    <li><a target="_top" href="zh-CN/text/swriter/guide/reset_format.html">重置字体属性</a></li>\
     <li><a target="_top" href="zh-CN/text/swriter/guide/stylist_fillformat.html">在填充格式模式中应用样式</a></li>\
     <li><a target="_top" href="zh-CN/text/swriter/guide/wrap.html">围绕对象的文字环绕</a></li>\
     <li><a target="_top" href="zh-CN/text/swriter/guide/text_centervert.html">利用框架使文字在页面上居中</a></li>\
@@ -1049,7 +1049,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="zh-CN/text/shared/01/02100001.html">正则表达式列表</a></li>\
 		</ul></li>\
 	</ul></li></ul>\
-    <ul><li><input type="checkbox" id="06"><label for="06">HTML 文档</label><ul>\
+    <ul><li><input type="checkbox" id="06"><label for="06">HTML 文档 (Writer Web)</label><ul>\
     <li><a target="_top" href="zh-CN/text/shared/07/09000000.html">网页</a></li>\
     <li><a target="_top" href="zh-CN/text/shared/02/01170700.html">HTML 筛选器和表单</a></li>\
     <li><a target="_top" href="zh-CN/text/swriter/guide/send2html.html">以 HTML 格式保存文本文档</a></li>\
